pub struct CertificateConfigurationUpdateForm {
metadata: Json<CertificateConfigurationUpdate>,
files: Vec<TempFile>,
}Fields
metadata: Json<CertificateConfigurationUpdate>files: Vec<TempFile>Trait Implementations
Sourceimpl MultipartCollect for CertificateConfigurationUpdateForm
impl MultipartCollect for CertificateConfigurationUpdateForm
Sourcefn limit(field_name: &str) -> Option<usize>
fn limit(field_name: &str) -> Option<usize>
An optional limit in bytes to be applied a given field name. Note this limit will be shared
across all fields sharing the same name.
Sourcefn handle_field<'t>(
req: &'t HttpRequest,
field: Field,
limits: &'t mut Limits,
state: &'t mut State,
) -> Pin<Box<dyn Future<Output = Result<(), MultipartError>> + 't>>
fn handle_field<'t>( req: &'t HttpRequest, field: Field, limits: &'t mut Limits, state: &'t mut State, ) -> Pin<Box<dyn Future<Output = Result<(), MultipartError>> + 't>>
The extractor will call this function for each incoming field, the state can be updated
with the processed field data.
Sourcefn from_state(state: State) -> Result<Self, MultipartError>
fn from_state(state: State) -> Result<Self, MultipartError>
Once all the fields have been processed and stored in the state, this is called
to convert into the struct representation.